import { defineComponent, $prefix, props, setup, h } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/upload/vue';
import UploadDragger from '@opentinyvue/vue-upload-dragger';
import Modal from '@opentinyvue/vue-modal';
import Tooltip from '@opentinyvue/vue-tooltip';
import { iconHelpCircle } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Upload",
  components: {
    TinyTooltip: Tooltip,
    TinyIconHelpCircle: iconHelpCircle()
  },
  props: [].concat(props, ["accept", "action", "autoUpload", "beforeUpload", "data", "disabled", "drag", "edmToken", "fileList", "headers", "httpRequest", "isFolder", "limit", "listType", "multiple", "name", "onError", "onExceed", "onPreview", "onProgress", "onRemove", "onStart", "onSuccess", "type", "withCredentials", "scale", "sourceType", "displayOnly", "customClass", "handleTriggerClick", "mode", "showTitle", "isHwh5", "tipMessage", "promptTip", "showFileList"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      h,
      extendOptions: {
        Modal
      }
    });
  },
  render: function render() {
    var h2 = arguments[0];
    var accept = this.accept, disabled = this.disabled, handleChange = this.handleChange, handleClick = this.handleClick, handleKeydown = this.handleKeydown, isFolder = this.isFolder, multiple = this.multiple, name = this.name, uploadFiles = this.uploadFiles, listType = this.listType, displayOnly = this.displayOnly, customClass = this.customClass, sourceType = this.sourceType, mode = this.mode, showTitle = this.showTitle, state = this.state, tipMessage = this.tipMessage, promptTip = this.promptTip, showFileList = this.showFileList;
    var defaultSlot = this.slots.default && this.slots.default();
    var tipSlot = this.slots.tip && this.slots.tip();
    var operateSlot = this.slots.operate && this.slots.operate();
    var isBubbleMode = mode === "bubble";
    var isShowTitle = showTitle;
    var popperConfig = {
      bubbling: true
    };
    var uploadTrigger = function uploadTrigger2() {
      return h2("div", {
        "attrs": {
          "data-tag": "tiny-upload-drag-single",
          "tabindex": "0"
        },
        "class": "h-full",
        "on": {
          "click": function click($event) {
            return handleClick($event, sourceType);
          },
          "keydown": handleKeydown
        }
      }, [listType === "drag-single" ? h2(UploadDragger, {
        "attrs": {
          "customClass": customClass,
          "disabled": disabled
        },
        "on": {
          "file": uploadFiles
        }
      }, [defaultSlot]) : defaultSlot]);
    };
    return h2("div", {
      "attrs": {
        "data-tag": "tiny-upload"
      },
      "class": [!displayOnly && listType === "text" ? "flex justify-between mt-4 mb-2 " + (isBubbleMode ? "sm:my-0" : !isShowTitle ? "sm:mt-0" : "sm:my-3") : "h-full", showFileList ? "sm:mb-3" : "sm:mb-0"]
    }, [state.currentBreakpoint === "default" && tipSlot && h2("div", {
      "class": "flex items-center sm:hidden inline-block text-sm"
    }, [tipSlot]), state.currentBreakpoint === "default" && uploadTrigger(), state.currentBreakpoint !== "default" && !displayOnly && (promptTip && tipMessage ? h2("div", {
      "class": "hidden sm:inline-flex sm:items-center w-full"
    }, [uploadTrigger(), h2("tiny-tooltip", {
      "attrs": {
        "effect": "light",
        "content": tipMessage,
        "placement": "right",
        "popper-options": popperConfig
      }
    }, [h2("tiny-icon-help-circle", {
      "attrs": {
        "custom-class": "ml-2 cursor-pointer fill-color-icon-tertiary"
      }
    })])]) : listType === "text" ? h2("div", {
      "class": "hidden sm:inline-flex sm:items-center w-full"
    }, [uploadTrigger(), h2("div", {
      "attrs": {
        "title": typeof tipMessage === "string" ? tipMessage : ""
      },
      "class": "hidden sm:block text-xs leading-4 overflow-hidden whitespace-nowrap text-ellipsis text-color-text-placeholder ml-2 cursor-pointer"
    }, [tipMessage])]) : h2("tiny-tooltip", {
      "attrs": {
        "effect": "light",
        "content": tipMessage,
        "placement": "top",
        "popper-options": popperConfig
      }
    }, [uploadTrigger()])), operateSlot, h2("input", {
      "class": "hidden",
      "attrs": {
        "type": "file",
        "webkitdirectory": isFolder,
        "name": name,
        "multiple": isFolder ? true : multiple,
        "accept": accept
      },
      "ref": "input",
      "on": {
        "change": handleChange
      }
    })]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
